@@ -15,14 +15,13 @@ try:
         gh_pages_build,
         gh_pages_clean,
         gh_pages_create,
-        gh_register) 
+        gh_register)
+    from git import Git
 except:
     info("github-tools' task not available")
 
-_here = os.path.dirname(os.path.abspath(__file__))
-sys.path.insert(0, os.path.join(_here, 'src'))
 
-import github.tools
+version='0.1.5'
 
 long_description = open('README.rst', 'r').read()
 
@@ -46,10 +45,12 @@ install_requires = [
     'PasteScript',
     'Cheetah',
     'virtualenv',
-    'GitPython'
+    'GitPython',
+    'pkginfo'
     ]
 
 try:
+    # available with python 2.6
     import json
 except ImportError:
     install_requires.append('simplejson')
@@ -60,16 +61,16 @@ entry_points="""
     gh_package = github.tools.template:GithubTemplate
     """
 
-setup(name=github.tools.PROJECT,
-    version=github.tools.RELEASE,
-    description=github.tools.DESCRIPTION,
+setup(name='github-tools',
+    version=version,
+    description='Helpers for Python package hosting at GitHub',
     long_description=long_description,
     classifiers=classifiers,
     keywords='sphinx, github, paster',
-    author=github.tools.AUTHOR,
-    author_email=github.tools.AUTHOR_EMAIL,
+    author='Damien Lebrun',
+    author_email='dinoboff@hotmail.com',
     url='http://dinoboff.github.com/github-tools/',
-    license=github.tools.LICENCE,
+    license='BSD',
     packages = find_packages('src'),
     package_dir = {'': 'src'},
     namespace_packages=['github'],
@@ -109,9 +110,27 @@ options(
 def sdist():
     """Overrides sdist to make sure that our setup.py is generated."""
 
+
 if 'gh_pages_build' in globals():
     
     @task
     @needs('gh_pages_build', 'github.tools.task.gh_pages_update')
     def gh_pages_update():
-        """Overrides github.tools.task to rebuild the doc (with sphinx)."""
\ No newline at end of file
+        """Overrides github.tools.task to rebuild the doc (with sphinx)."""
+    
+    
+    tag_name = 'v%s' % version
+    
+    @task
+    def tag():
+        """tag a new version of this distribution"""
+        git = Git('.')
+        git.pull('origin', 'master')
+        git.tag(tag_name)
+    
+    
+    @task
+    @needs('sdist', 'tag', 'setuptools.command.upload', 'gh_pages_update')
+    def upload():
+        """Upload the distribution to pypi, the new tag and the doc to Github"""
+        Git('.').push('origin', 'master', tag_name)
\ No newline at end of file
